summaryrefslogtreecommitdiff
path: root/keyboards
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards')
-rw-r--r--keyboards/ergodox/keymaps/familiar/README.md4
-rw-r--r--keyboards/ergodox/keymaps/familiar/keymap.c22
2 files changed, 13 insertions, 13 deletions
diff --git a/keyboards/ergodox/keymaps/familiar/README.md b/keyboards/ergodox/keymaps/familiar/README.md
index 7252f571a..7e3bce406 100644
--- a/keyboards/ergodox/keymaps/familiar/README.md
+++ b/keyboards/ergodox/keymaps/familiar/README.md
@@ -1,5 +1,5 @@
# ErgoDox Familiar Layout
-Familiar layout for those who regularly switch back and forth from ErgoDox to regular QWERTY.
+Familiar layout for those who regularly switch back and forth from ErgoDox to "normal" QWERTY.
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](../../../../license_GPLv3.md../../../../license_GPLv3.md) [![standard-readme compliant](https://img.shields.io/badge/readme%20style-standard-brightgreen.svg)](https://github.com/RichardLitt/standard-readme)
@@ -50,7 +50,7 @@ $ make ergodox-ez-familiar-teensy
### Layers
1. Base Layer: QWERTY, with arrow keys at bottom right.
1. UCIS Layer: US-International symbols layer, plus —. Accessed by toggling the `INTL` layer using the UCIS key (bottom of left thumb cluster).
-1. UCIS-Shifted Layer: Making shift work for UCIS characters. An ugly workaround. Any ideas? Accessed through holding shift while the UCIS layer is active (toggles the `INSF` layer).
+1. UCIS-Shifted Layer: Making shift work for UCIS characters. An ugly workaround. Any ideas? Accessed by holding shift while the UCIS layer is active (toggles the `INSF` layer).
1. Numpad Layer: Right hand number pad. Accessed by toggling the `NUMP` layer using the NPAD key (bottom of right thumb cluster).
1. Function Layer: F1-F12, arrows on ESDF and HJKL, media player controls. Accessed by holding either FN key (center key of each thumb cluster), which toggles the `ARRW` layer. I know, I need to work on my naming conventions.
diff --git a/keyboards/ergodox/keymaps/familiar/keymap.c b/keyboards/ergodox/keymaps/familiar/keymap.c
index c5f94afda..714118d93 100644
--- a/keyboards/ergodox/keymaps/familiar/keymap.c
+++ b/keyboards/ergodox/keymaps/familiar/keymap.c
@@ -28,13 +28,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |--------+------+------+------+------+------| END | | PGDN |------+------+------+------+------+--------|
* | (/LSFT | Z | X | C | V | B | | | | N | M | , | . | UP | )/RSFT |
* `--------+------+------+------+------+-------------' `-------------+------+------+------+------+--------'
* | LCTRL | LGUI | MENU | ' | " | | [ | ] | LEFT | DOWN | RIGHT |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.
- * | VOL- | VOL+ | | | |
+ * | VOL- | VOL+ | |PRTSCR| |
* ,------|------|------| |------+------+------.
- * | SPC/ |SLASH/| MUTE | |NUMLCK|WHACK/| SPC/ |
- * | ALT | MO(1)|------| |------|MO(1) | ALT |
+ * | |SLASH/| MUTE | |NUMLCK|WHACK/| |
+ * | SPC | MO(1)|------| |------|MO(1) | SPC |
* | | | LAY3 | | LAY2 | | |
* `--------------------' `--------------------'
*/
@@ -44,19 +44,19 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_HOME,
KC_GRV, KC_A, KC_S, KC_D, KC_F, KC_G,
KC_LSPO, KC_Z, KC_X, KC_C, KC_V, KC_B, KC_END,
- KC_LCTL, KC_LGUI, KC_MENU, KC_QUOT, S(KC_QUOT),
+ KC_LCTL, KC_LGUI, KC_MENU, KC_QUOT, KC_LALT,
KC_VOLD, KC_VOLU,
KC_MUTE,
- ALT_T(KC_SPC), LT(ARRW,KC_SLSH), TG(INTL),
+ KC_SPC, LT(ARRW, KC_SLSH), TG(INTL),
// right hand
KC_7, KC_8, KC_9, KC_0, KC_MINS, KC_EQL, KC_BSPC,
KC_PGUP, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_DEL,
KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_ENTER,
KC_PGDN, KC_N, KC_M, KC_COMM, KC_DOT, KC_UP, KC_RSPC,
- KC_LBRC, KC_RBRC, KC_LEFT, KC_DOWN, KC_RGHT,
- _______, _______,
+ MT(MOD_RALT, KC_LBRC), KC_RBRC, KC_LEFT, KC_DOWN, KC_RGHT,
+ KC_PSCR, _______,
KC_NLCK,
- TG(NUMP), LT(ARRW,KC_BSLS), ALT_T(KC_SPC)
+ TG(NUMP), LT(ARRW, C_BSLS), KC_SPC
),
/* layer 1: International symbols, etc
@@ -202,7 +202,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | | | | | | | | | HOME | PGDN | END |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.
- * | | PAUSE| | | |
+ * | | PAUSE| |SYSREQ| |
* ,------|------|------| |------+------+------.
* | | | | |SCRLK | | |
* | | |------| |------| | |
@@ -225,7 +225,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_LEFT, KC_DOWN, KC_UP, KC_RGHT, _______, _______,
_______, _______, _______, _______, _______, KC_PGUP, _______,
_______, _______, KC_HOME, KC_PGDN, KC_END,
- _______, _______,
+ KC_SYSREQ, _______,
KC_SLCK,
_______, _______, _______
),
@@ -28,13 +28,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | (/LSFT | Z | X | C | V | B | | | | N | M | , | . | UP | )/RSFT |
* `--------+------+------+------+------+-------------' `-------------+------+------+------+------+--------'
- * | LCTRL | LGUI | MENU | ' | " | | [ | ] | LEFT | DOWN | RIGHT |
+ * | LCTRL | LGUI | MENU | ' | LALT | |[/RALT| ] | LEFT | DOWN | RIGHT |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.